@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008, Nokia
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -33,7 +33,7 @@
 
 #include <dbus/dbus-glib-bindings.h>
 
-#include <libtracker-common/tracker-storage.h>
+#include <libtracker-miner/tracker-miner.h>
 
 #include "tracker-albumart.h"
 #include "tracker-dbus.h"
@@ -46,7 +46,7 @@
 #define ALBUMARTER_INTERFACE  "com.nokia.albumart.Requester"
 
 typedef struct {
-	TrackerStorage *hal;
+	TrackerStorage *storage;
 	gchar *art_path;
 	gchar *local_uri;
 } GetFileInfo;
@@ -548,7 +548,7 @@ albumart_set (const unsigned char *buffer,
 }
 
 static void
-albumart_request_download (TrackerStorage *hal,
+albumart_request_download (TrackerStorage *storage,
                            const gchar    *album,
                            const gchar    *artist,
                            const gchar    *local_uri,
@@ -562,11 +562,7 @@ albumart_request_download (TrackerStorage *hal,
 
 	info = g_slice_new (GetFileInfo);
 
-#ifdef HAVE_HAL
-	info->hal = hal ? g_object_ref (hal) : NULL;
-#else
-	info->hal = NULL;
-#endif
+	info->storage = storage ? g_object_ref (storage) : NULL;
 
 	info->local_uri = g_strdup (local_uri);
 	info->art_path = g_strdup (art_path);
@@ -600,17 +596,16 @@ albumart_request_download (TrackerStorage *hal,
 }
 
 static void
-albumart_copy_to_local (TrackerStorage *hal,
+albumart_copy_to_local (TrackerStorage *storage,
                         const gchar    *filename,
                         const gchar    *local_uri)
 {
-	GSList *removable_roots, *l;
+	GSList *roots, *l;
 	gboolean on_removable_device = FALSE;
 	guint flen;
 
 	/* Determining if we are on a removable device */
-#ifdef HAVE_HAL
-	if (!hal) {
+	if (!storage) {
 		/* This is usually because we are running on the
 		 * command line, so we don't error here with
 		 * g_return_if_fail().
@@ -618,15 +613,10 @@ albumart_copy_to_local (TrackerStorage *hal,
 		return;
 	}
 
-	removable_roots = tracker_storage_get_removable_device_roots (hal);
-#else
-	removable_roots = g_slist_append (removable_roots, "/media");
-	removable_roots = g_slist_append (removable_roots, "/mnt");
-#endif
-
+	roots = tracker_storage_get_device_roots (storage, TRACKER_STORAGE_REMOVABLE, FALSE);
 	flen = strlen (filename);
 
-	for (l = removable_roots; l; l = l->next) {
+	for (l = roots; l; l = l->next) {
 		guint len;
 
 		len = strlen (l->data);
@@ -637,11 +627,8 @@ albumart_copy_to_local (TrackerStorage *hal,
 		}
 	}
 
-#ifdef HAVE_HAL
-	g_slist_foreach (removable_roots, (GFunc) g_free, NULL);
-#endif
-
-	g_slist_free (removable_roots);
+	g_slist_foreach (roots, (GFunc) g_free, NULL);
+	g_slist_free (roots);
 
 	if (on_removable_device) {
 		GFile *local_file, *from;
@@ -697,10 +684,10 @@ albumart_queue_cb (DBusGProxy     *proxy,
 		g_clear_error (&error);
 	}
 
-	if (info->hal && info->art_path &&
+	if (info->storage && info->art_path &&
 	    g_file_test (info->art_path, G_FILE_TEST_EXISTS)) {
 
-		albumart_copy_to_local (info->hal,
+		albumart_copy_to_local (info->storage,
 		                        info->art_path,
 		                        info->local_uri);
 	}
@@ -708,8 +695,8 @@ albumart_queue_cb (DBusGProxy     *proxy,
 	g_free (info->art_path);
 	g_free (info->local_uri);
 
-	if (info->hal) {
-		g_object_unref (info->hal);
+	if (info->storage) {
+		g_object_unref (info->storage);
 	}
 
 	g_slice_free (GetFileInfo, info);
@@ -723,11 +710,7 @@ tracker_albumart_init (void)
 
 	g_return_val_if_fail (initialized == FALSE, FALSE);
 
-#ifdef HAVE_HAL
 	albumart_storage = tracker_storage_new ();
-#else  /* HAVE_HAL */
-	albumart_storage = NULL;
-#endif /* HAVE_HAL */
 
 	/* Cache to know if we have already handled uris */
 	albumart_cache = g_hash_table_new_full (g_str_hash,
@@ -769,11 +752,9 @@ tracker_albumart_shutdown (void)
 		g_hash_table_unref (albumart_cache);
 	}
 
-#ifdef HAVE_HAL
 	if (albumart_storage) {
 		g_object_unref (albumart_storage);
 	}
-#endif /* HAVE_HAL */
 
 	initialized = FALSE;
 }
