@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
- * Copyright (C) 2008, Nokia
+ * Copyright (C) 2006, Jamie McCracken <jamiemcc@gnome.org>
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -58,12 +58,6 @@
 #include "tracker-store.h"
 #include "tracker-statistics.h"
 
-#ifdef G_OS_WIN32
-#include <windows.h>
-#include <pthread.h>
-#include "mingw-compat.h"
-#endif
-
 #define ABOUT	  \
 	"Tracker " PACKAGE_VERSION "\n"
 
@@ -342,6 +336,9 @@ main (gint argc, gchar *argv[])
 	TrackerConfig *config;
 	TrackerDBManagerFlags flags = 0;
 	gboolean is_first_time_index;
+	TrackerStatus *notifier;
+	gpointer busy_user_data;
+	TrackerBusyCallback busy_callback;
 
 	g_type_init ();
 
@@ -450,13 +447,24 @@ main (gint argc, gchar *argv[])
 		flags |= TRACKER_DB_MANAGER_LOW_MEMORY_MODE;
 	}
 
+	notifier = tracker_dbus_register_notifier ();
+	busy_callback = tracker_status_get_callback (notifier, 
+	                                            &busy_user_data);
+
 	if (!tracker_data_manager_init (flags,
 	                                NULL,
 	                                &is_first_time_index,
-	                                TRUE)) {
+	                                TRUE,
+	                                busy_callback,
+	                                busy_user_data,
+	                                "Journal replaying")) {
+
+		g_object_unref (notifier);
 		return EXIT_FAILURE;
 	}
 
+	g_object_unref (notifier);
+
 	tracker_store_init ();
 
 	if (private->shutdown) {
